==> avogadro-debuginfo-1.2.0-4.tar.xz: usr/src/debug/avogadro-1.2.0-4/libavogadro/src/tools/qrc_bondcentrictool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/avogadro/avogadro-1.2.0-4.i686/src/avogadro-1.2.0/libavogadro/src/tools/bondcentric.png
  0x0,0x0,0x2,0xbb,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x8,0x6,0x0,0x0,0x0,0x73,0x7a,0x7a,0xf4,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,
  0xa7,0x93,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,
  0xb,0x13,0x1,0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,
  0xd7,0x6,0x19,0x17,0x3a,0x2c,0x6f,0xa6,0x6c,0xed,0x0,0x0,0x2,0x48,0x49,0x44,
  0x41,0x54,0x58,0xc3,0xed,0x97,0x4f,0x48,0x54,0x51,0x14,0xc6,0x7f,0x3a,0x3a,0x93,
  0x51,0x2e,0x82,0xc,0xa9,0x16,0x49,0x94,0x38,0xcc,0x22,0x8,0x1c,0xdc,0x44,0xa1,
  0xd9,0x1f,0x84,0x36,0x42,0x6d,0x5a,0x47,0x10,0x67,0x15,0x88,0x2b,0xa1,0x5d,0xad,
  0xdc,0xd9,0x26,0xa3,0xc8,0x95,0x61,0x8,0x62,0x45,0xc4,0x6c,0xba,0x8b,0xfe,0xd0,
  0xa6,0x50,0xe9,0x35,0x61,0x11,0x4,0x91,0x30,0x65,0x8a,0x56,0x4c,0x9b,0x33,0x70,
  0x39,0xcc,0x7b,0xbd,0xd1,0x99,0x5a,0x34,0x7,0x1e,0xe7,0xde,0xef,0x7c,0xf7,0xdc,
  0xef,0xdd,0xfb,0xde,0x79,0xf7,0xc1,0xff,0x6e,0xd,0x5e,0xbb,0x18,0x82,0xd7,0xd4,
  0x1a,0xff,0xf5,0xa,0xd4,0x5,0xd4,0x5,0x54,0x22,0x20,0xd,0x4c,0x2,0x9f,0x81,
  0x35,0x60,0x1e,0xb8,0xc,0x34,0x95,0xe1,0xa6,0x80,0x11,0x20,0xaf,0xdc,0xbc,0xf6,
  0x93,0x51,0x13,0x14,0xbd,0xcb,0xda,0x21,0x60,0xd9,0x70,0x4a,0xd7,0x78,0x19,0xfe,
  0xdd,0x10,0xee,0xe4,0x46,0x5,0x3c,0x50,0x7c,0x16,0x38,0xa0,0x77,0x7d,0x10,0x78,
  0xa8,0xf8,0x11,0x8f,0x7b,0x42,0xb1,0x2,0xd0,0xf,0x6c,0x51,0x5f,0x50,0xfc,0xf8,
  0x46,0x4,0x94,0xee,0xbe,0xcd,0xe0,0xbb,0x14,0xbf,0xe1,0x61,0xb7,0x15,0x1b,0x32,
  0xdc,0x21,0xc5,0x6f,0xfd,0x51,0x80,0x38,0x79,0x69,0x62,0x2b,0x1a,0xdb,0x69,0xf0,
  0x36,0xc5,0x5f,0x7b,0xd8,0xbc,0x62,0x19,0xc3,0xcd,0x28,0x3e,0x17,0xe7,0x21,0xfc,
  0x2a,0x4e,0xa6,0xbd,0xfe,0x73,0xf5,0xe3,0xc0,0x7e,0x20,0xa1,0x5b,0x71,0x53,0xf1,
  0xbd,0x1e,0x77,0xb7,0xfa,0xbc,0xc9,0x99,0x37,0xf1,0x48,0x1,0xdd,0x40,0xbf,0x38,
  0x79,0xa2,0xfd,0x11,0xe0,0x17,0x70,0x1a,0x78,0x3,0xfc,0x4,0x16,0x80,0xef,0x1a,
  0xdf,0xea,0x8d,0x2d,0xb5,0x57,0x4d,0xce,0xd5,0x32,0xdc,0x50,0x1,0x6f,0x81,0x66,
  0x20,0x2b,0x4e,0x9e,0x2,0x8f,0x81,0x5e,0x20,0xa7,0x93,0x2e,0x3,0xd7,0x81,0x6b,
  0xca,0xff,0x66,0xb6,0xb,0xa0,0xc5,0xe4,0x6c,0x31,0xf1,0x48,0x1,0x9d,0xfa,0x45,
  0x6c,0x4,0xe,0x8b,0x93,0x47,0x3a,0xf9,0x51,0x60,0x1b,0xb0,0x1d,0xb8,0x0,0x64,
  0x95,0xbf,0xe0,0x8d,0xfd,0xa8,0x7e,0x9f,0xc9,0xd9,0x61,0xe2,0xb1,0xb,0x51,0x3,
  0x70,0x4c,0x9c,0xcc,0x19,0x3c,0x9,0x5c,0xd4,0xf6,0x7d,0xf,0x7f,0xa6,0xfe,0x94,
  0xe1,0x9f,0x34,0xcf,0x53,0xa4,0x80,0x1f,0x56,0xc4,0xcc,0xf0,0x4c,0xe7,0xe0,0xd8,
  0xe0,0x2b,0x9d,0xb8,0xb,0x98,0xd2,0x5a,0x50,0x0,0xc6,0x3c,0xee,0x84,0xfa,0x61,
  0xa0,0x4f,0xab,0x62,0x9f,0xf6,0x1,0xee,0xf8,0x89,0x9b,0x42,0x4,0x24,0x2c,0x10,
  0xe4,0x2,0x82,0x5c,0x90,0xd6,0xd2,0xea,0xb,0x3d,0xf,0x7c,0xf2,0xb0,0x59,0xe0,
  0x1e,0x70,0x46,0xb,0x95,0x6f,0x53,0x66,0xb5,0xc2,0x5f,0x43,0x7b,0x52,0x1a,0xb8,
  0x3a,0x40,0x7b,0xa6,0x9d,0x44,0x73,0x82,0x54,0x6b,0xaa,0xa8,0xc9,0xb2,0xc0,0x74,
  0x99,0xf1,0x67,0x81,0x2b,0xc0,0xa2,0x8a,0x5c,0xd4,0xfe,0xb9,0x58,0x47,0x32,0x71,
  0xb2,0xa6,0x4b,0x17,0x65,0xeb,0xa3,0x3d,0xa3,0x29,0x36,0x69,0x61,0x2b,0x90,0x8c,
  0x31,0x36,0x29,0x4e,0x82,0x5a,0x9,0x58,0x8a,0x39,0xbe,0x43,0x9c,0xbc,0xaf,0x85,
  0x80,0x1d,0x15,0x9c,0xaa,0xf7,0x88,0x93,0x17,0xe2,0xa4,0xb7,0x9a,0x2,0x2a,0x3d,
  0x96,0xa7,0x81,0x4b,0xd5,0x14,0x50,0x34,0xdb,0xb1,0x62,0xbe,0x98,0x4b,0xc0,0x17,
  0x7d,0x25,0x3f,0x68,0x29,0xee,0x12,0x27,0xef,0xaa,0xf5,0x63,0xf2,0xd7,0x7e,0x8a,
  0xea,0xa7,0xe2,0xba,0xfd,0x6,0x7a,0x64,0xa8,0xb4,0x36,0x17,0x6e,0xea,0x0,0x0,
  0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // bondcentric
  0x0,0xb,
  0x9,0x97,0x71,0xb3,
  0x0,0x62,
  0x0,0x6f,0x0,0x6e,0x0,0x64,0x0,0x63,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x69,0x0,0x63,
    // bondcentric.png
  0x0,0xf,
  0x1,0xa9,0x79,0xa7,
  0x0,0x62,
  0x0,0x6f,0x0,0x6e,0x0,0x64,0x0,0x63,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x69,0x0,0x63,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/bondcentric
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/bondcentric/bondcentric.png
  0x0,0x0,0x0,0x1c,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_bondcentrictool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_bondcentrictool))

int QT_MANGLE_NAMESPACE(qCleanupResources_bondcentrictool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_bondcentrictool))

==> avogadro-debuginfo-1.2.0-5.tar.xz: usr/src/debug/avogadro-1.2.0-5/libavogadro/src/tools/qrc_bondcentrictool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /wip/cygport-git/avogadro/avogadro-1.2.0-5.x86_64/src/avogadro-1.2.0/libavogadro/src/tools/bondcentric.png
  0x0,0x0,0x2,0xbb,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x8,0x6,0x0,0x0,0x0,0x73,0x7a,0x7a,0xf4,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,
  0xa7,0x93,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,
  0xb,0x13,0x1,0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,
  0xd7,0x6,0x19,0x17,0x3a,0x2c,0x6f,0xa6,0x6c,0xed,0x0,0x0,0x2,0x48,0x49,0x44,
  0x41,0x54,0x58,0xc3,0xed,0x97,0x4f,0x48,0x54,0x51,0x14,0xc6,0x7f,0x3a,0x3a,0x93,
  0x51,0x2e,0x82,0xc,0xa9,0x16,0x49,0x94,0x38,0xcc,0x22,0x8,0x1c,0xdc,0x44,0xa1,
  0xd9,0x1f,0x84,0x36,0x42,0x6d,0x5a,0x47,0x10,0x67,0x15,0x88,0x2b,0xa1,0x5d,0xad,
  0xdc,0xd9,0x26,0xa3,0xc8,0x95,0x61,0x8,0x62,0x45,0xc4,0x6c,0xba,0x8b,0xfe,0xd0,
  0xa6,0x50,0xe9,0x35,0x61,0x11,0x4,0x91,0x30,0x65,0x8a,0x56,0x4c,0x9b,0x33,0x70,
  0x39,0xcc,0x7b,0xbd,0xd1,0x99,0x5a,0x34,0x7,0x1e,0xe7,0xde,0xef,0x7c,0xf7,0xdc,
  0xef,0xdd,0xfb,0xde,0x79,0xf7,0xc1,0xff,0x6e,0xd,0x5e,0xbb,0x18,0x82,0xd7,0xd4,
  0x1a,0xff,0xf5,0xa,0xd4,0x5,0xd4,0x5,0x54,0x22,0x20,0xd,0x4c,0x2,0x9f,0x81,
  0x35,0x60,0x1e,0xb8,0xc,0x34,0x95,0xe1,0xa6,0x80,0x11,0x20,0xaf,0xdc,0xbc,0xf6,
  0x93,0x51,0x13,0x14,0xbd,0xcb,0xda,0x21,0x60,0xd9,0x70,0x4a,0xd7,0x78,0x19,0xfe,
  0xdd,0x10,0xee,0xe4,0x46,0x5,0x3c,0x50,0x7c,0x16,0x38,0xa0,0x77,0x7d,0x10,0x78,
  0xa8,0xf8,0x11,0x8f,0x7b,0x42,0xb1,0x2,0xd0,0xf,0x6c,0x51,0x5f,0x50,0xfc,0xf8,
  0x46,0x4,0x94,0xee,0xbe,0xcd,0xe0,0xbb,0x14,0xbf,0xe1,0x61,0xb7,0x15,0x1b,0x32,
  0xdc,0x21,0xc5,0x6f,0xfd,0x51,0x80,0x38,0x79,0x69,0x62,0x2b,0x1a,0xdb,0x69,0xf0,
  0x36,0xc5,0x5f,0x7b,0xd8,0xbc,0x62,0x19,0xc3,0xcd,0x28,0x3e,0x17,0xe7,0x21,0xfc,
  0x2a,0x4e,0xa6,0xbd,0xfe,0x73,0xf5,0xe3,0xc0,0x7e,0x20,0xa1,0x5b,0x71,0x53,0xf1,
  0xbd,0x1e,0x77,0xb7,0xfa,0xbc,0xc9,0x99,0x37,0xf1,0x48,0x1,0xdd,0x40,0xbf,0x38,
  0x79,0xa2,0xfd,0x11,0xe0,0x17,0x70,0x1a,0x78,0x3,0xfc,0x4,0x16,0x80,0xef,0x1a,
  0xdf,0xea,0x8d,0x2d,0xb5,0x57,0x4d,0xce,0xd5,0x32,0xdc,0x50,0x1,0x6f,0x81,0x66,
  0x20,0x2b,0x4e,0x9e,0x2,0x8f,0x81,0x5e,0x20,0xa7,0x93,0x2e,0x3,0xd7,0x81,0x6b,
  0xca,0xff,0x66,0xb6,0xb,0xa0,0xc5,0xe4,0x6c,0x31,0xf1,0x48,0x1,0x9d,0xfa,0x45,
  0x6c,0x4,0xe,0x8b,0x93,0x47,0x3a,0xf9,0x51,0x60,0x1b,0xb0,0x1d,0xb8,0x0,0x64,
  0x95,0xbf,0xe0,0x8d,0xfd,0xa8,0x7e,0x9f,0xc9,0xd9,0x61,0xe2,0xb1,0xb,0x51,0x3,
  0x70,0x4c,0x9c,0xcc,0x19,0x3c,0x9,0x5c,0xd4,0xf6,0x7d,0xf,0x7f,0xa6,0xfe,0x94,
  0xe1,0x9f,0x34,0xcf,0x53,0xa4,0x80,0x1f,0x56,0xc4,0xcc,0xf0,0x4c,0xe7,0xe0,0xd8,
  0xe0,0x2b,0x9d,0xb8,0xb,0x98,0xd2,0x5a,0x50,0x0,0xc6,0x3c,0xee,0x84,0xfa,0x61,
  0xa0,0x4f,0xab,0x62,0x9f,0xf6,0x1,0xee,0xf8,0x89,0x9b,0x42,0x4,0x24,0x2c,0x10,
  0xe4,0x2,0x82,0x5c,0x90,0xd6,0xd2,0xea,0xb,0x3d,0xf,0x7c,0xf2,0xb0,0x59,0xe0,
  0x1e,0x70,0x46,0xb,0x95,0x6f,0x53,0x66,0xb5,0xc2,0x5f,0x43,0x7b,0x52,0x1a,0xb8,
  0x3a,0x40,0x7b,0xa6,0x9d,0x44,0x73,0x82,0x54,0x6b,0xaa,0xa8,0xc9,0xb2,0xc0,0x74,
  0x99,0xf1,0x67,0x81,0x2b,0xc0,0xa2,0x8a,0x5c,0xd4,0xfe,0xb9,0x58,0x47,0x32,0x71,
  0xb2,0xa6,0x4b,0x17,0x65,0xeb,0xa3,0x3d,0xa3,0x29,0x36,0x69,0x61,0x2b,0x90,0x8c,
  0x31,0x36,0x29,0x4e,0x82,0x5a,0x9,0x58,0x8a,0x39,0xbe,0x43,0x9c,0xbc,0xaf,0x85,
  0x80,0x1d,0x15,0x9c,0xaa,0xf7,0x88,0x93,0x17,0xe2,0xa4,0xb7,0x9a,0x2,0x2a,0x3d,
  0x96,0xa7,0x81,0x4b,0xd5,0x14,0x50,0x34,0xdb,0xb1,0x62,0xbe,0x98,0x4b,0xc0,0x17,
  0x7d,0x25,0x3f,0x68,0x29,0xee,0x12,0x27,0xef,0xaa,0xf5,0x63,0xf2,0xd7,0x7e,0x8a,
  0xea,0xa7,0xe2,0xba,0xfd,0x6,0x7a,0x64,0xa8,0xb4,0x36,0x17,0x6e,0xea,0x0,0x0,
  0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // bondcentric
  0x0,0xb,
  0x9,0x97,0x71,0xb3,
  0x0,0x62,
  0x0,0x6f,0x0,0x6e,0x0,0x64,0x0,0x63,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x69,0x0,0x63,
    // bondcentric.png
  0x0,0xf,
  0x1,0xa9,0x79,0xa7,
  0x0,0x62,
  0x0,0x6f,0x0,0x6e,0x0,0x64,0x0,0x63,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x69,0x0,0x63,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/bondcentric
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/bondcentric/bondcentric.png
  0x0,0x0,0x0,0x1c,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_bondcentrictool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_bondcentrictool))

int QT_MANGLE_NAMESPACE(qCleanupResources_bondcentrictool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_bondcentrictool))
